embassy-stm32

Crates

git

Versions

stm32u595aj

Flavors

MDF1

Struct MDF1 

pub struct MDF1 { /* private fields */ }
MDF1 peripheral

Implementations

Source

impl MDF1

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.